#======================================================================
#    This file is part of Absence.
#
#    Absence is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Absence is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Absence.  If not, see <http://www.gnu.org/licenses/>.
#======================================================================

# $Id: AbsenceInput.pm 111 2013-10-20 17:57:24Z urban $
# copyright Robert Urban

package AbsenceInput;

use Encode qw(decode_utf8);

require Exporter;
@ISA = qw(Exporter);
@EXPORT_OK = qw(validate_input);
@EXPORT = qw(validate_input);

my $VERSION = '2.0.1';

sub validate_input
{
	my $ref = shift;

	my $res = undef;
	my @out;

	for(my $i = 0; $i < $#{ $ref }; $i += 2) {
		my ($name, $type);
		my ($tag, $val) = @{ $ref }[$i, $i+1];
		if (!defined($val) || length($val) == 0) { next; }
		if (ref($val)) {
			($name, $type, $val) = ($tag, $val->[0], $val->[1]);
		} else {
			($name, $type) = ($tag, $tag);
		}

		my @vals = ref($val) ? @{ $val } : ($val);
		foreach my $v (@vals) {
			my $r = check_val($tag, $type, $v);
			defined($r) && push(@out, $r);
		}
	}

	return @out ? join("<BR>\n", @out)."<BR>\n" : undef;
}

sub check_val
{
	my ($tag, $type, $val) = @_;

	$val = decode_utf8($val);

	#----------------------------------------------
	# validate value
	#----------------------------------------------
	if ($type eq 'num') {
		($val =~ /^\d+$/) || return "$tag [$val] contains non-digit chars";
	}
	elsif ($type eq 'username') {
		if ($val !~ /^[a-z0-9_.,]+$/i) {
			my $tmp = $val;
			$tmp =~ s![a-z0-9_.,]!!ig;
			return "username [$val] contains illegal chars [$tmp] (allowed: a-z0-9_.,)";
		}
	}
	elsif ($type eq 'acl') {
		($val =~ /^\d+:\d+$/) || return "acl [$val] illegal";
	}
	elsif ($type eq 'name') {
		if ($val =~ m![\000-\037\\`]!) {
			return "name [$val] contains illegal chars";
		}
		#if ($val !~ m!^[-a-z0-9_,./ ]+$!i) {
		#	my $tmp = $val;
		#	$tmp =~ s![-a-z0-9_,./ ]!!ig;
		#	return "name [$val] contains illegal chars [$tmp] (allowed: a-z0-9.,/- and blank)";
		#}
	}
	elsif ($type eq 'description') {
		($val =~ m{^[-a-z0-9_,!./ ]+$}i)
			|| return "description [$val] contains illegal chars (allowed: a-z0-9!.,/-)";
	}
	elsif ($type eq 'email') {
		($val =~ /^[-a-z0-9_.]+@([-a-z0-9]+\.?)+$/i)
			|| return "email [$val] invalid";
	}

	return undef;
}

1;
