#!/usr/bin/perl

use DBI;
use Carp;

my $DB_NAME		= 'absence';
my $DB_HOST		= 'localhost';
my $DB_USER		= 'absence';
my $DB_PASS		= 'absence';

my $DBH = DBI->connect("dbi:Pg:dbname=$DB_NAME",
    $DB_USER, $DB_PASS, {AutoCommit => 1, RaiseError => 1});

my $user_id = shift || 2;
print "using User-ID=$user_id\n";

my @groups = findReadableGroups($user_id);
print "Groups: ",join(', ', @groups), "\n";

defined($DBH) && $DBH->disconnect;

#========================================================================

sub findReadableGroups
{
    my $user_id = shift;

    my %unique_groups;

    #---------------------------------------------------------------
    # first find all groups to which the object associated with
    # $user_id belongs (if any)
    # next, look at access records
    #---------------------------------------------------------------

    my $sql = qq{
        SELECT map.group_id
        FROM
            c_group_object  AS map,
            v_user          AS u
        WHERE
            (u.id           = $user_id AND
             map.object_id  = u.object_id)
        UNION
        SELECT ref_id AS group_id
        FROM c_access
        WHERE
            (user_id        = $user_id) AND
            (type           = 'group') AND
            (ref_id         IS NOT NULL);
    };

    my $sth = $DBH->prepare($sql);
	$sth->execute || confess "statement [$sql] failed";
    my $tbl_ary_ref = $sth->fetchall_arrayref([0]);

    my @result;
    foreach my $row (@{$tbl_ary_ref}) {
        push(@result, $row->[0]);
    }

    @result;
}

sub dbSelect
{
    my $sql = shift;

    my $sth;
    eval {
        $sth = $DBH->prepare($sql);
    };
    if ($@) {
        confess $@;
    }

    $sth->execute || confess "statement [$sql] failed";

    my @result;
    my $ref;
    while(defined($ref = $sth->fetchrow_hashref)) {
        push(@result, $ref);
    }

    if (wantarray) {
        return @result;
    } else {
        @result || return undef;
        return $result[0];
    }
}

