package AbsenceCurrent;

use FileHandle;
use Fcntl ':flock'; # import LOCK_* constants
use Carp;

use AbsenceConfig;
use AbsenceLog;

my $CURRENT_FILE	= AbsenceConfig::fetch('current_file');
my %CURRENT;
my $VERSION			= '1.1';

_init();

sub fetch
{
	my $gid = shift;

	exists($CURRENT{$gid}) || return ();

	return @{$CURRENT{$gid}};
}

#------------------------------------------------------------
# current month/day file routines
#------------------------------------------------------------

sub _init
{
	my $fh = _open() || return;
	_read($fh);
	_close($fh);
}

sub _open
{
	if (! -e $CURRENT_FILE) { return undef; }
	my $fh = FileHandle->new($CURRENT_FILE);
	defined($fh) || die "open on $CURRENT_FILE failed";

	$fh;
}

sub _close
{
	my $fh = shift;
	$fh->close;
}

sub _read
{
	my $fh = shift;

	my $line_num = 1;
	while(<$fh>) {
		chomp;
		next if /^\s*$/;
		next if /^\s*#/;
		my ($gid, $day, $month, $year) = (/^(\d+):(\d+)\.(\d+)\.(\d+)$/);
		#abslog("DBG: gid=$gid, day=$day, month=$month, year=$year");
		if (defined($gid)) {
			$CURRENT{$gid} = [$day, $month, $year];
		} else {
			abslog("cannot parse current at line $line_num [$_]");
		}
	} continue {
		$line_num++;
	}
}

sub update
{
	my $gid = shift;

	# open for read and write
	my $openstr = (-e $CURRENT_FILE) ? "+<$CURRENT_FILE" : ">$CURRENT_FILE";
	my $fh = FileHandle->new($openstr);
	defined($fh) || confess "open on $CURRENT_FILE failed";

	# lock
	flock($fh, LOCK_EX) || die "flock lock_ex on $CURRENT_FILE ($!)";

	# re-read to be safe
	_read($fh);

	# update current group-ID in array
	my ($day, $month, $year) = (localtime)[3,4,5];
	$month++;
	$year += 1900;
	$CURRENT{$gid} = [$day, $month, $year];

	# seek to beginning
	seek($fh, 0, 0) || die "seek";

	# truncate ...
	truncate($fh, 0) || die "truncate";

	# ... and write 
	foreach my $gid (keys(%CURRENT)) {
		print $fh "$gid:", join('.', @{$CURRENT{$gid}}), "\n";
	}

	flock($fh, LOCK_UN) || die "flock lock_un on $CURRENT_FILE ($!)";
	$fh->close;
}

1;
