#!/usr/local/bin/bash

#======================================================================
#    This file is part of Absence.
#
#    Absence is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Absence is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Absence.  If not, see <http://www.gnu.org/licenses/>.
#======================================================================

#-----------------------------------------------------------------------
# $id$
# copyright Robert Urban
#-----------------------------------------------------------------------

run_cmd() {
	typeset cmd=$1
	[[ $VERBOSE -eq 1 ]] && echo "cmd: [$cmd]"
	eval $cmd
	if [ $? -ne 0 ]; then
		echo "COMMAND FAILED: [$cmd]  exiting."
		exit 1
	fi
}

HERE=$(dirname $0)
echo "HERE=[$HERE]"

VERBOSE=1
DB_ADMIN_USER="postgres"
DB_NAME="absence-ldw"
DB_DESC="absence data"
DB_USER="absence"
DB_PASS="absence"
CREATE_TABLES_SCRIPT="$HERE/create_tables.sql"
CREATE_TABLES_LOG="/tmp/create_tables.log"
PSQL_CMD="psql -U $DB_ADMIN_USER"

PATH=/bin:/usr/bin:/usr/local/bin

#---------------------------------------------------------------------
# create DB Owner
#---------------------------------------------------------------------
if $PSQL_CMD -c "SELECT rolname FROM pg_roles where rolname = '$DB_USER';" template1 | grep '1 row'; then
	echo "user $DB_USER exists"
else
	#$PSQL_CMD -c "create user $DB_USER with password '$DB_PASS';"
	$PSQL_CMD -c "CREATE ROLE $DB_USER NOSUPERUSER CREATEDB NOCREATEROLE INHERIT LOGIN;"
	$PSQL_CMD -c "ALTER USER $DB_USER ENCRYPTED PASSWORD '$DB_PASS';" template1
fi

#cmd="create user $DB_USER with password '$DB_PASS' createdb;"
#cmd="create user $DB_USER createdb;"
#psql -c "$cmd" template1

#psql -c "ALTER USER $DB_USER WITH PASSWORD '$DB_PASS';" template1

#---------------------------------------------------------------------
# create DB
#---------------------------------------------------------------------
echo "dropping database..."
out=$(dropdb -U $DB_ADMIN_USER $DB_NAME 2>&1)
if [ $? -ne 0 ]; then
	if [[ "$out" != *not\ exist* ]]; then
		echo "dropdb command failed. exiting."
		exit 1
	fi
fi
run_cmd "createdb -U $DB_USER -E UTF8 -O $DB_USER $DB_NAME '$DB_DESC'"

#---------------------------------------------------------------------
# create tables
#---------------------------------------------------------------------
psql -U $DB_USER -d "$DB_NAME" -f $CREATE_TABLES_SCRIPT -o $CREATE_TABLES_LOG
echo "psql return-code = $?"
#cat $CREATE_TABLES_SCRIPT | psql -d "$DB_NAME" -f - -o $CREATE_TABLES_LOG

echo "finished creating database."
