#!/usr/bin/perl

#======================================================================
#    This file is part of Absence.
#
#    Absence is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Absence is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Absence.  If not, see <http://www.gnu.org/licenses/>.
#======================================================================

# copyright Robert Urban

use AbsenceImport;

my %VALUES = (
	database_user	=> 'absence',
	database_pass	=> 'absence',
	database_name	=> 'absence',
	database_host	=> undef,
);

importCountries('..');

sub importCountries
{
	my $srcdir = shift;

	AbsenceImport::init(
		$VALUES{database_user},
		$VALUES{database_pass}, 
		$VALUES{database_name}, 
		$VALUES{database_host}, 
	);

	verbose("loading country names and codes into database");

	my $input_file = "$srcdir/misc/iso3166-countrycodes.txt";
	my $fh = FileHandle->new($input_file);
	defined($fh)
		|| die "failed to open iso-country-code file [$input_file]: $!";
	my $parsing = 0;
	my @list;
	while(<$fh>) {
		chomp;
		next if (/^\s*$/);
		if ($parsing) {
			if (/^(\S+(?:\s+\S+)*?)\s+(\S{2})\s+(\S{3})\s+(\d{3})\s*$/) {
				my ($name, $two, $three, $num) = ($1, $2, $3, $4);
				push(@list, { code => $two, name => $name });
				verbose("code=[$two], name=[$name]");
			}
		}
		elsif (/^-{50,}$/) {
			$parsing = 1;
		}
	}
	$fh->close;

	AbsenceImport::loadCountryTable(\@list);
}

sub verbose
{
	my $msg = shift;

	print "$msg\n";
}
